==> r_assets-0.2.1.tar.gz: lib/generate_r_file/generate_support_files.dart <==
const svgSupportString = """
/// 使用svg库，为统一assets贮备资源
/// https://pub.dev/packages/flutter_svg/install
import 'dart:async';
import 'dart:ui' as ui show Codec, Image, Picture, ImageByteFormat;
import 'dart:ui';

import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart' show rootBundle;
import 'package:flutter/widgets.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:path/path.dart' as path;

///
/// 目前使用方式：
/// ```
/// SvgPicture.asset(R.svg.capsuleAddNewPlusSvg(width: 50.0, height: 50.0).asset),
/// ```
///
/// TODO：优化Svg库提供的：PictureProvider<dynamic>类型才能使用
/// ```
/// SvgPicture(R.svg.capsuleAddNewPlusSvg(width: 50.0, height: 50.0)),
/// ```
class AssetSvg extends ImageProvider<AssetSvg> {
  final String asset;
  final double width;
  final double height;

  const AssetSvg(this.asset, {this.width = 100, this.height = 100})
      : assert(asset != null),
        assert(width != null),
        assert(height != null);

  @override
  Future<AssetSvg> obtainKey(ImageConfiguration configuration) {
    return SynchronousFuture<AssetSvg>(this);
  }

  @override
  ImageStreamCompleter load(AssetSvg key, DecoderCallback decode) {
    return MultiFrameImageStreamCompleter(
      codec: _loadAsync(key),
      scale: 1.0,
    );
  }

  Future<ui.Codec> _loadAsync(AssetSvg key) async {
    assert(key == this);

    var rawSvg = await rootBundle.loadString(asset);
    final DrawableRoot svgRoot = await svg.fromSvgString(rawSvg, rawSvg);
    final scale = window.devicePixelRatio;
    final ui.Picture picture = svgRoot.toPicture(
      size: Size(
        width.toDouble() * scale,
        height.toDouble() * scale,
      ),
      clipToViewBox: false,
    );
    var imageW = (width * scale).toInt();
    var imageH = (height * scale).toInt();
    final ui.Image image = await picture.toImage(imageW, imageH);
    var imageData = await image.toByteData(format: ui.ImageByteFormat.png);

    return PaintingBinding.instance.instantiateImageCodec(imageData.buffer.asUint8List());
  }

  @override
  bool operator ==(dynamic other) {
    if (other.runtimeType != runtimeType) return false;
    final AssetSvg typedOther = other;
    return asset == typedOther.asset && width == typedOther.width && height == typedOther.height;
  }

  @override
  int get hashCode => hashValues(asset.hashCode, width, height, 1.0);

  @override
  String toString() => '\$runtimeType(\${describeIdentity(asset)}, scale: 1.0)';
}

/// Asset resource’s metadata class.
/// For example, here is the metadata of `packages/flutter_demo/assets/images/example.png` asset:
/// - packageName：flutter_demo
/// - assetName：assets/images/example.png
/// - fileDirname：assets/images
/// - fileBasename：example.png
/// - fileBasenameNoExtension：example
/// - fileExtname：.png
class AssetResource {
  /// Creates an object to hold the asset resource’s metadata.
  const AssetResource(this.assetName, {this.packageName}) : assert(assetName != null);

  /// The name of the main asset from the set of asset resources to choose from.
  final String assetName;

  /// The name of the package from which the asset resource is included.
  final String packageName;

  /// The name used to generate the key to obtain the asset resource. For local assets
  /// this is [assetName], and for assets from packages the [assetName] is
  /// prefixed 'packages/<package_name>/'.
  String get keyName => packageName == null ? assetName : "packages/\$packageName/\$assetName";

  /// The file basename of the asset resource.
  String get fileBasename {
    final basename = path.basename(assetName);
    return basename;
  }

  /// The no extension file basename of the asset resource.
  String get fileBasenameNoExtension {
    final basenameWithoutExtension = path.basenameWithoutExtension(assetName);
    return basenameWithoutExtension;
  }

  /// The file extension name of the asset resource.
  String get fileExtname {
    final extension = path.extension(assetName);
    return extension;
  }

  /// The directory path name of the asset resource.
  String get fileDirname {
    var dirname = assetName;
    if (packageName != null) {
      final packageStr = "packages/\$packageName/";
      dirname = dirname.replaceAll(packageStr, "");
    }
    final filenameStr = "\$fileBasename/";
    dirname = dirname.replaceAll(filenameStr, "");
    return dirname;
  }
}
""";

==> r_assets-0.2.3.tar.gz: lib/generate_r_file/generate_support_files.dart <==
const svgSupportString = """
/// 使用svg库，为统一assets贮备资源
/// https://pub.dev/packages/flutter_svg/install
import 'dart:async';
import 'dart:ui' as ui show Codec, Image, Picture, ImageByteFormat;
import 'dart:ui';

import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart' show rootBundle;
import 'package:flutter/widgets.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:path/path.dart' as path;

///
/// 目前使用方式：
/// ```
/// SvgPicture.asset(R.svg.capsuleAddNewPlusSvg(width: 50.0, height: 50.0).asset),
/// ```
///
/// TODO：优化Svg库提供的：PictureProvider<dynamic>类型才能使用
/// ```
/// SvgPicture(R.svg.capsuleAddNewPlusSvg(width: 50.0, height: 50.0)),
/// ```
class AssetSvg extends ImageProvider<AssetSvg> {
  final String asset;
  final double width;
  final double height;

  const AssetSvg(this.asset, {this.width = 100, this.height = 100})
      : assert(asset != null),
        assert(width != null),
        assert(height != null);

  @override
  Future<AssetSvg> obtainKey(ImageConfiguration configuration) {
    return SynchronousFuture<AssetSvg>(this);
  }

  @override
  ImageStreamCompleter load(AssetSvg key, DecoderCallback decode) {
    return MultiFrameImageStreamCompleter(
      codec: _loadAsync(key),
      scale: 1.0,
    );
  }

  Future<ui.Codec> _loadAsync(AssetSvg key) async {
    assert(key == this);

    var rawSvg = await rootBundle.loadString(asset);
    final DrawableRoot svgRoot = await svg.fromSvgString(rawSvg, rawSvg);
    final scale = window.devicePixelRatio;
    final ui.Picture picture = svgRoot.toPicture(
      size: Size(
        width.toDouble() * scale,
        height.toDouble() * scale,
      ),
      clipToViewBox: false,
    );
    var imageW = (width * scale).toInt();
    var imageH = (height * scale).toInt();
    final ui.Image image = await picture.toImage(imageW, imageH);
    var imageData = await image.toByteData(format: ui.ImageByteFormat.png);

    return PaintingBinding.instance!.instantiateImageCodec(imageData!.buffer.asUint8List());
  }

  @override
  bool operator ==(dynamic other) {
    if (other.runtimeType != runtimeType) return false;
    final AssetSvg typedOther = other;
    return asset == typedOther.asset && width == typedOther.width && height == typedOther.height;
  }

  @override
  int get hashCode => hashValues(asset.hashCode, width, height, 1.0);

  @override
  String toString() => '\$runtimeType(\${describeIdentity(asset)}, scale: 1.0)';
}

/// Asset resource’s metadata class.
/// For example, here is the metadata of `packages/flutter_demo/assets/images/example.png` asset:
/// - packageName：flutter_demo
/// - assetName：assets/images/example.png
/// - fileDirname：assets/images
/// - fileBasename：example.png
/// - fileBasenameNoExtension：example
/// - fileExtname：.png
class AssetResource {
  /// Creates an object to hold the asset resource’s metadata.
  const AssetResource(this.assetName, {this.packageName = ''}) : assert(assetName != null);

  /// The name of the main asset from the set of asset resources to choose from.
  final String assetName;

  /// The name of the package from which the asset resource is included.
  final String packageName;

  /// The name used to generate the key to obtain the asset resource. For local assets
  /// this is [assetName], and for assets from packages the [assetName] is
  /// prefixed 'packages/<package_name>/'.
  String get keyName => packageName == null ? assetName : "packages/\$packageName/\$assetName";

  /// The file basename of the asset resource.
  String get fileBasename {
    final basename = path.basename(assetName);
    return basename;
  }

  /// The no extension file basename of the asset resource.
  String get fileBasenameNoExtension {
    final basenameWithoutExtension = path.basenameWithoutExtension(assetName);
    return basenameWithoutExtension;
  }

  /// The file extension name of the asset resource.
  String get fileExtname {
    final extension = path.extension(assetName);
    return extension;
  }

  /// The directory path name of the asset resource.
  String get fileDirname {
    var dirname = assetName;
    if (packageName != null) {
      final packageStr = "packages/\$packageName/";
      dirname = dirname.replaceAll(packageStr, "");
    }
    final filenameStr = "\$fileBasename/";
    dirname = dirname.replaceAll(filenameStr, "");
    return dirname;
  }
}
""";
